************************************************************************
*
*  File: NUGETTS
*
*  Returns the TestCases in the given TestSuite for the given user and library.
*
*  Tags: NUNIT
*
*  Parameters:
*    NUGETTSP.USERNAME  - The username.
*    NUGETTSP.LIBRARY   - The library.
*    NUGETTSP.TESTSUITE - The TestSuite's name.
*
*  Returns:
*    NUGETTSP.MESSAGE   - The error message (if any).
*    NUGETTSP.TESTCASES - The TestCases for the TestSuite.
*
*  About:
*    Library       - NUNIT
*    Erstellt      - 29.08.2009
*    Autor         - $Author: Stefan $
*    Revison       - $LastChangedRevision: 264 $
*    Letzter Autor - $LastChangedBy: Stefan $
*    Modifiziert   - $Date: 2009-08-31 12:44:42 +0200 (Mo, 31 Aug 2009) $
*    Id            - $Id: NUGETTS.NSS 264 2009-08-31 10:44:42Z Stefan $
************************************************************************
*
DEFINE DATA
*
PARAMETER USING NUGETTSP
*
LOCAL USING NUGETTCP
*
LOCAL
01 #LINES (A200/1:*)
01 #NUM-LINES (N8)
01 #LINE (A) DYNAMIC
01 #L (N8)
*
01 #SUITENAME-LENGTH (N3)
01 #SUITENAME (A) DYNAMIC
01 #IN-SUITE (L)
01 #SUITE-FOUND (L)
*
01 #TC (N8)
*
END-DEFINE
*
************************************************************************
DEFINE SUBROUTINE GET-TESTSUITE
************************************************************************
*
* only read TestCase file if TestCases are not already set
#NUM-LINES := *OCCURRENCE(NUGETTSP.TESTCASES)
IF #NUM-LINES EQ 0
  PERFORM READ-TESTCASE-FILE NUGETTSP.USERNAME #LINES(*) NUGETTSP.MESSAGE 
ELSE
  RESIZE ARRAY #LINES TO (1:#NUM-LINES) 
  MOVE NUGETTSP.TESTCASES(*) TO #LINES(*) 
  REDUCE ARRAY NUGETTSP.TESTCASES TO 0 
END-IF
*
#IN-SUITE := FALSE
#SUITE-FOUND := FALSE
FOR #L 1 *OCCURRENCE(#LINES)
*
  #LINE := *TRIM(#LINES(#L)) 
  IF *LENGTH(#LINE) EQ 0 
    ESCAPE TOP 
  END-IF 
*
* comments start with #
  IF SUBSTRING(#LINE, 1, 1) EQ '#' 
    ESCAPE TOP 
  END-IF 
*
* TestSuites start with [
  IF SUBSTRING(#LINE, 1, 1) EQ '[' 
    #SUITENAME-LENGTH := *LENGTH(#LINE) - 2 
    #SUITENAME := SUBSTRING(#LINE, 2, #SUITENAME-LENGTH) 
    IF #SUITENAME EQ NUGETTSP.TESTSUITE 
      #IN-SUITE := TRUE 
      #SUITE-FOUND := TRUE 
    ELSE 
      #IN-SUITE := FALSE 
    END-IF 
    ESCAPE TOP 
  END-IF 
*
  IF #IN-SUITE 
    ADD 1 TO #TC 
    RESIZE ARRAY NUGETTSP.TESTCASES TO (1:#TC) 
    NUGETTSP.TESTCASES(#TC) := #LINE 
  END-IF 
*
END-FOR
*
IF NOT #SUITE-FOUND
  COMPRESS 'TestSuite not found: <' NUGETTSP.TESTSUITE '>' 
    INTO NUGETTSP.MESSAGE 
  REDUCE ARRAY NUGETTSP.TESTCASES TO 0 
  ESCAPE MODULE 
END-IF
*
#NUM-LINES := *OCCURRENCE(NUGETTSP.TESTCASES)
IF #NUM-LINES EQ 0
  COMPRESS 'No TestCases found for TestSuite <' NUGETTSP.TESTSUITE '>' 
    INTO NUGETTSP.MESSAGE 
  REDUCE ARRAY NUGETTSP.TESTCASES TO 0 
  ESCAPE MODULE 
END-IF
*
RESIZE ARRAY NUGETTCP.TESTCASES TO (1:#NUM-LINES)
MOVE BY NAME NUGETTSP TO NUGETTCP
PERFORM GET-TESTCASES NUGETTCP
*
#NUM-LINES := *OCCURRENCE(NUGETTCP.TESTCASES)
IF #NUM-LINES EQ 0
  COMPRESS 'No TestCases found for TestSuite <' NUGETTSP.TESTSUITE '>' 
    INTO NUGETTSP.MESSAGE 
  REDUCE ARRAY NUGETTSP.TESTCASES TO 0 
  ESCAPE MODULE 
END-IF
*
RESIZE ARRAY NUGETTSP.TESTCASES TO (1:#NUM-LINES)
MOVE NUGETTCP.TESTCASES(*) TO NUGETTSP.TESTCASES(*)
*
ON ERROR
  IF *ERROR-NR EQ 1314 /* Target field too small for field portion 
    COMPRESS NUMERIC 'Invalid TestCase: <' #LINE '> in line' #L 
      INTO NUGETTSP.MESSAGE 
    REDUCE ARRAY NUGETTSP.TESTCASES TO 0 
    ESCAPE MODULE 
  END-IF 
END-ERROR
END-SUBROUTINE
*
END
